coef.lqmix: Print the estimated coefficients of an 'lqmix' object

View source: R/coef.lqmix.R

coef.lqmixR Documentation

Print the estimated coefficients of an lqmix object

Description

Print the estimated coefficients of a fitted model stored in an object of class lqmix.

Usage

## S3 method for class 'lqmix'
coef(object, ...)

Arguments

object

an lqmix object

...

not used

Value

Return the estimated coefficients in the longitudinal data model obtained at convergence of the EM algorithm for a fitted model of class lqmix.


lqmix documentation built on Nov. 5, 2025, 7:15 p.m.