coef.lqr: Print the estimated coefficients of an 'lqr' object

View source: R/coef.lqr.R

coef.lqrR Documentation

Print the estimated coefficients of an lqr object

Description

Print the estimated coefficients of a fitted model stored in an object of class lqr.

Usage

## S3 method for class 'lqr'
coef(object, ...)

Arguments

object

an lqmix object

...

not used

Value

Return the estimated coefficients for a fitted model of class lqr.


lqmix documentation built on Nov. 5, 2025, 7:15 p.m.