coef.search_lqmix: Printn the estimated coefficients for the optimal fitted...

View source: R/coef.seach_lqmix.R

coef.search_lqmixR Documentation

Printn the estimated coefficients for the optimal fitted model

Description

Print the estimated coefficients of the optimal fitted model stored in an object of class search_lqmix.

Usage

## S3 method for class 'search_lqmix'
coef(object, ...)

Arguments

object

a search_lqmix object

...

not used

Value

Return the estimated coefficients obtained at convergence of the EM algorithm for the optimal model obtained at convergence of the EM algorithm for a fitted model of class search_lqmix.


lqmix documentation built on Nov. 5, 2025, 7:15 p.m.