dal: Density of the Asymmetric Laplace Distribution

dalR Documentation

Density of the Asymmetric Laplace Distribution

Description

Compute the density for the three parameter Asymmetric Laplace Distribution.

Usage

dal(y, mu = 0, sigma = 1, qtl = 0.5, log = FALSE)

Arguments

y

vector of quantiles

mu

location parameter

sigma

scale parameter

qtl

skewness parameter

log

logical; if TRUE, probabilities are log-transformed

Details

The function computes the density of the Asymmetric Laplace distribution, with location \mu, scale \sigma > 0 and skewness qtl = q in (0,1), as discussed by Koenker and Machado (1999) and Yu and Moyeed (2001), according to the following expression

f(y | \mu, \sigma, q) = \frac{q(1-q)}{\sigma} \exp(-\rho_{q} (\frac{y-\mu}{\sigma}))

Value

Return the density for the Asymmetric Laplace Distribution.

References

\insertRef

ref:dal1lqmix

\insertRef

ref:dal2lqmix

\insertRef

ref:dal3lqmix


lqmix documentation built on Nov. 5, 2025, 7:15 p.m.