View source: R/logLik.search_lqmix.R
| logLik.search_lqmix | R Documentation |
search_lqmix objectPrint the log-likelihood of an optimal fitted model stored in an object of class search_lqmix.
## S3 method for class 'search_lqmix'
logLik(object, ...)
object |
an |
... |
not used |
Return an object of class logLik providing the log-likelihood value at convergence of the EM algorithm for a fitted model of class lqmix.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.