| lqr | R Documentation |
Estimate a linear quantile regression model for independent data (no random coefficients).
lqr(formula, data, qtl = 0.5, se = TRUE, R = 100, verbose = TRUE,
seed = NULL, parallel = FALSE, ncores = 2, ...)
formula |
an object of class |
data |
a data frame containing the variables named in |
qtl |
quantile to be estimated |
se |
standard error computation |
R |
number of bootstrap samples for computing standard errors |
verbose |
if set to FALSE, no printed output is given during the function execution |
seed |
an integer value for random numbers generation, used for bootstrap standard errors |
parallel |
if set to TRUE, a parallelized code is use for standard error computation (if se=TRUE) |
ncores |
number of cores used for computing bootstrap standard errors (if required) |
... |
not used |
The function computes ML estimates for the parameters of a linear quantile regression model for independent observations. Estimates are derived by maximizing the (log-)likelihood of a Laplace regression, where the location parameter is modeled as a function of fixed coefficients only.
If se=TRUE, standard errors based on a bootstrap procedure are computed.
Return an object of class lqr. This is a list containing the following elements:
betaf |
a vector containing fixed regression coefficients |
scale |
the scale parameter |
sigma.e |
the standard deviation of error terms |
lk |
the log-likelihood |
npar |
the total number of model parameters |
AIC |
the AIC value |
BIC |
the BIC value |
qtl |
the estimated quantile |
nobs |
the total number of observations |
se.betaf |
the standard errors for the regression coefficients |
se.scale |
the standard error for the scale parameter |
model |
the estimated model |
mmf |
the model matrix associated to the regression coefficients |
y |
the model response |
call |
the matched call |
formula |
the model formula |
ref:KoeBaslqmix
out0 = lqr(formula=meas~trt+time+trt:time,data=pain,se=TRUE,R=10)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.