The pain data frame consists of a total of 357 rows and 4 columns providing information on pain levels of 83 women in labor, followed for up 6 measurement occasions.
data(pain)A data frame with 357 observations on the following 5 variables:
idwoman id
measa numeric vector of self-reported pain scores on a 100mm line
trta dummy variable with values 1 for subjects who received a pain medication and 0 for subjects who received a placebo
timea numeric vector of times (minutes since randomization) at which pain was measured
The data set consists of repeated measurements of self-reported pain on n = 83 women. 43 women were randomly assigned to a pain medication group and 40 to a placebo group. The response was measured every 30 minutes on a 100-mm line: 0 means no pain and 100 means extreme pain. The number of measurements for each woman varies from 1 to 6. Data are severely skewed, and the skewness changes magnitude, and even sign, over time.
ref:painlqmix