predict.lqmix: Predictions from an 'lqmix' object

predict.lqmixR Documentation

Predictions from an lqmix object

Description

Returns the predicted values for an object of class lqmix.

Usage

## S3 method for class 'lqmix'
predict(object, newdata = NULL, ...)

Arguments

object

an lqmix object

newdata

an optional data frame in which to look for variables with which to predict. If omitted, the fitted values are produced

...

not used

Details

The function computes predictions for an object of class lqmix. If the fitted model is based on TC, discrete, random coefficients only, a matrix of size nsbjs x G is given as output; if the fitted model is based on TV, discrete, random coefficients only, a matrix of size nObs x m; if the fitted model is based on both TC and TV, discrete, random coefficients, an array of size nObs x G x m is returned.

Value

A matrix or an array of predictions, based on the estimated model.


lqmix documentation built on Nov. 5, 2025, 7:15 p.m.