| predict.lqr | R Documentation |
lqr objectReturns the predicted values for an object of class lqr.
## S3 method for class 'lqr'
predict(object, newdata = NULL, ...)
object |
an |
newdata |
an optional data frame in which to look for variables with which to predict. If omitted, the fitted values are produced |
... |
not used |
The function computes predictions for an object of class lqr.
A vector of predictions.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.