predict.search_lqmix: Predictions from the optimal fitted model

predict.search_lqmixR Documentation

Predictions from the optimal fitted model

Description

Returns the predicted values of the optimal fitted model stored in an object of class search_lqmix.

Usage

## S3 method for class 'search_lqmix'
predict(object, newdata = NULL, ...)

Arguments

object

a search_lqmix object

newdata

an optional data frame in which to look for variables with which to predict. If omitted, the fitted values are produced

...

not used

Details

The function computes predictions for the optimal fitted model stored in an object of class search_lqmix. If the optimal fitted model is based on TC, discrete, random coefficients only, a matrix of size nsbjs x G is given as output; if the optimal fitted model is based on TV, discrete, random coefficients only, a matrix of size nObs x m; if the optimal fitted model is based on both TC and TV, discrete, random coefficients, an array of size nObs x G x m is returned.

Value

A vector, a matrix, or an array of predictions, based on the optimal fitted model.


lqmix documentation built on Nov. 5, 2025, 7:15 p.m.