View source: R/print.summary.lqr.R
| print.summary.lqr | R Documentation |
lqr objectPrint the summary of an an object of class lqr.
## S3 method for class 'summary.lqr'
print(x, digits = max(3, getOption("digits") - 3), ...)
x |
a summary of an |
digits |
a non-null value for digits specifying the minimum number of significant digits to be printed |
... |
not used |
Return a summary of an lqr object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.