View source: R/print.summary.search_lqmix.R
| print.summary.search_lqmix | R Documentation |
search_lqmix objectPrint the summary of an object of class search_lqmix.
## S3 method for class 'summary.search_lqmix'
print(x, digits = max(3, getOption("digits") -
3), ...)
x |
a summary of a |
digits |
a non-null value for digits specifying the minimum number of significant digits to be printed |
... |
not used |
Return a summary of a search_lqmix object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.