residuals.search_lqmix: Residuals from the optimal fitted model

residuals.search_lqmixR Documentation

Residuals from the optimal fitted model

Description

Returns the residuals from the optimal fitted model stored in an object of class search_lqmix.

Usage

## S3 method for class 'search_lqmix'
residuals(object, ...)

Arguments

object

an search_lqmix object

...

not used

Details

The function computes residuals for the optimal fitted model stored in an object of class search_lqmix. If the optimal fitted model is based on TC, discrete, random coefficients only, a matrix of size nsbjs x G is given as output; if the optimal fitted model is based on TV, discrete, random coefficients only, a matrix a matrix of size nObs x m is given as output is given as output; if the optimal fitted model is based on both TC and TV, discrete, random coefficients, an array of size nObs x G x m is returned.

Value

A vector, a matrix, or an array of of residuals, based on the estimated model.


lqmix documentation built on Nov. 5, 2025, 7:15 p.m.