Learn R Programming

lqmix (version 1.2)

summary.search_lqmix: Summary of a search_lqmix object

Description

Summary method for the class search_lqmix.

Usage

# S3 method for search_lqmix
summary(object, ...)

Value

Return an object of class

summary.search_lqmix. This is a list of summary statistics for the optimal linear quantile mixture model given in object$optimal, with the following elements:

fix

a matrix with estimates, standard errors, Z statistics, and p-values for the fixed regression coefficients for the optimal fitted model

ranTC

a matrix with estimates, standard errors, Z statistics, and p-values for the TC random coefficients, if present for the optimal fitted model

ranTV

a matrix with estimates, standard errors, Z statistics, and p-values for the TV random coefficients, if present for the optimal fitted model

pg

a matrix with estimates and standard errors for the prior probabilities of the finite mixture associated to TC random coefficients, if present for the optimal fitted model

delta

a matrix with estimates and standard errors for the initial probabilities of the hidden Markov chain associated to TV random coefficients, if present for the optimal fitted model

Gamma

a matrix with estimates and standard errors for the transition probabilities of the hidden Markov chain associated to TV random coefficients, if present for the optimal fitted model

scale

the scale parameter for the optimal model

sigma.e

the standard deviation of error terms for the optimal model

logLik

the log-likelihood at convergence of the EM algorithm for the optimal model

npar

the total number of model parameters for the optimal model

AIC

the AIC value for the optimal model

BIC

the BIC value for the optimal model

qtl

the estimated quantile

G

the number of mixture components associated to TC random coefficients, if present for the optimal fitted model

m

the number of hidden states associated to TV random coefficients, if present for the optimal fitted model

nsbj

the number of subjects

nobs

the total number of observations

miss

the missingness type

model

the identified optimal model

call

the matched call

Arguments

object

a search_lqmix object

...

not used