vcov.lqmix: Calculate variance-covariance matrix for a fitted 'lqmix'...

View source: R/vcov.lqmix.R

vcov.lqmixR Documentation

Calculate variance-covariance matrix for a fitted lqmix object

Description

Return the bootstrap variance-covariance matrix for the coefficients of a fitted lqmix object.

Usage

## S3 method for class 'lqmix'
vcov(object, ...)

Arguments

object

an lqmix object

...

not used

Value

A matrix of the estimated covariances between the parameter estimates in the linear predictor of the model.


lqmix documentation built on Nov. 5, 2025, 7:15 p.m.