vcov.lqr: Calculate variance-covariance matrix for a fitted 'lqr'...

View source: R/vcov.lqr.R

vcov.lqrR Documentation

Calculate variance-covariance matrix for a fitted lqr object

Description

Return the bootstrap variance-covariance matrix for the parameters of a fitted lqr object.

Usage

## S3 method for class 'lqr'
vcov(object, ...)

Arguments

object

an lqmix object

...

not used

Value

A matrix of the estimated covariances between the parameter estimates in the linear predictor of the model.


lqmix documentation built on Nov. 5, 2025, 7:15 p.m.