vcov.search_lqmix: Calculate variance-covariance matrix for the optimal fitted...

View source: R/vcov.search_lqmix.R

vcov.search_lqmixR Documentation

Calculate variance-covariance matrix for the optimal fitted model

Description

Return the bootstrap variance-covariance matrix of the parameters of the optimal fitted model stored in an object of class search_lqmix.

Usage

## S3 method for class 'search_lqmix'
vcov(object, ...)

Arguments

object

an search_lqmix object

...

not used

Value

A matrix of the estimated covariances between the main parameter estimates in the linear predictor of the model.


lqmix documentation built on Nov. 5, 2025, 7:15 p.m.