| coef.lqmix | R Documentation |
lqmix objectPrint the estimated coefficients of a fitted model stored in an object of class lqmix.
## S3 method for class 'lqmix'
coef(object, ...)
object |
an |
... |
not used |
Return the estimated coefficients in the longitudinal data model obtained at convergence of the EM algorithm for a fitted model of class lqmix.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.