Learn R Programming

lqmix (version 1.2)

coef.lqmix: Print the estimated coefficients of an lqmix object

Description

Print the estimated coefficients of a fitted model stored in an object of class lqmix.

Usage

# S3 method for lqmix
coef(object, ...)

Value

Return the estimated coefficients in the longitudinal data model obtained at convergence of the EM algorithm for a fitted model of class

lqmix.

Arguments

object

an lqmix object

...

not used