| coef.lqr | R Documentation |
lqr objectPrint the estimated coefficients of a fitted model stored in an object of class lqr.
## S3 method for class 'lqr'
coef(object, ...)
object |
an |
... |
not used |
Return the estimated coefficients for a fitted model of class lqr.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.