coef.lqr: Print the estimated coefficients of an lqr object
Description
Print the estimated coefficients of a fitted model stored in an object of class lqr.
Usage
# S3 method for lqr
coef(object, ...)
Value
Return the estimated coefficients for a fitted model of class
lqr.
Arguments
- object
an lqmix object
- ...
not used