coef.lqr: Print the estimated fixed coefficients of an lqr object
Description
Print the estimated fixed coefficients of a fitted model of class lqr
Usage
# S3 method for lqr
coef(object, ...)
Value
Return the estimated coefficients obtained at convergence of the EM algorithm for a fitted model of class
lqr
Arguments
- object
an lqmix object
- ...
not used