View source: R/coef.seach_lqmix.R
| coef.search_lqmix | R Documentation |
Print the estimated coefficients of the optimal fitted model stored in an object of class search_lqmix.
## S3 method for class 'search_lqmix'
coef(object, ...)
object |
a |
... |
not used |
Return the estimated coefficients obtained at convergence of the EM algorithm for the optimal model obtained at convergence of the EM algorithm for a fitted model of class search_lqmix.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.