Learn R Programming

lqmix (version 1.2)

coef.search_lqmix: Printn the estimated coefficients for the optimal fitted model

Description

Print the estimated coefficients of the optimal fitted model stored in an object of class search_lqmix.

Usage

# S3 method for search_lqmix
coef(object, ...)

Value

Return the estimated coefficients obtained at convergence of the EM algorithm for the optimal model obtained at convergence of the EM algorithm for a fitted model of class

search_lqmix.

Arguments

object

a search_lqmix object

...

not used