Print the estimated coefficients of the optimal fitted model stored in an object of class search_lqmix.
# S3 method for search_lqmix
coef(object, ...)Return the estimated coefficients obtained at convergence of the EM algorithm for the optimal model obtained at convergence of the EM algorithm for a fitted model of class
search_lqmix.
a search_lqmix object
not used