search_lqmix objectPrint the estimated fixed coefficients of the optimal fitted model stored in an object of class search_lqmix
# S3 method for search_lqmix
coef(object, ...)Return the estimated fixed coefficients obtained at convergence of the EM algorithm for the optimal model stored in an object of class
search_lqmix
a search_lqmix object
not used