| predict.lqmix | R Documentation |
lqmix objectReturns the predicted values for an object of class lqmix.
## S3 method for class 'lqmix'
predict(object, newdata = NULL, ...)
object |
an |
newdata |
an optional data frame in which to look for variables with which to predict. If omitted, the fitted values are produced |
... |
not used |
The function computes predictions for an object of class lqmix.
If the fitted model is based on TC, discrete, random coefficients only, a matrix of size nsbjs x G is given as output; if the fitted model is based on TV, discrete, random coefficients only, a matrix of size nObs x m; if the fitted model is based on both TC and TV, discrete, random coefficients, an array of size nObs x G x m is returned.
A matrix or an array of predictions, based on the estimated model.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.