| predict.search_lqmix | R Documentation |
Returns the predicted values of the optimal fitted model stored in an object of class search_lqmix.
## S3 method for class 'search_lqmix'
predict(object, newdata = NULL, ...)
object |
a |
newdata |
an optional data frame in which to look for variables with which to predict. If omitted, the fitted values are produced |
... |
not used |
The function computes predictions for the optimal fitted model stored in an object of class search_lqmix.
If the optimal fitted model is based on TC, discrete, random coefficients only, a matrix of size nsbjs x G is given as output; if the optimal fitted model is based on TV, discrete, random coefficients only, a matrix of size nObs x m; if the optimal fitted model is based on both TC and TV, discrete, random coefficients, an array of size nObs x G x m is returned.
A vector, a matrix, or an array of predictions, based on the optimal fitted model.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.