| residuals.lqmix | R Documentation |
lqmix objectReturns the residuals from a fitted lqmix object.
## S3 method for class 'lqmix'
residuals(object, ...)
object |
an |
... |
not used |
The function computes residuals for an object of class lqmix.
If the fitted model is based on TC, discrete, random coefficients only, a matrix of size nsbjs x G is given as output; if the fitted model is based on TV, discrete, random coefficients only, a matrix a matrix of size nObs x m is given as output is given as output; if the fitted model is based on both TC and TV, discrete, random coefficients, an array of size nObs x G x m is returned.
If the estimated model is based on TC, discrete, random coefficients only, a matrix is given as output. The number of columns corresponds to the estimated number of components (G).
If the estimated model is based on TV, discrete, random coefficients only, a matrix is given as output. The number of columns corresponds to the estimated number of states (m).
If the estimated model is based on both TC and TV, discrete, random coefficients, an array is given as output. The second and third dimensions correspond to the estimated number of components (G) and states (m), respectively.
A matrix or an array of of residuals, based on the estimated model.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.