search_lqmix objectSummary method for the class search_lqmix.
# S3 method for search_lqmix
summary(object, ...)Return an object of class
summary.search_lqmix.
This is a list of summary statistics for the optimal linear quantile mixture model given in object$optimal, with the following elements:
a matrix with estimates, standard errors, Z statistics, and p-values for the fixed regression coefficients for the optimal fitted model
a matrix with estimates, standard errors, Z statistics, and p-values for the TC random coefficients, if present for the optimal fitted model
a matrix with estimates, standard errors, Z statistics, and p-values for the TV random coefficients, if present for the optimal fitted model
a matrix with estimates and standard errors for the prior probabilities of the finite mixture associated to TC random coefficients, if present for the optimal fitted model
a matrix with estimates and standard errors for the initial probabilities of the hidden Markov chain associated to TV random coefficients, if present for the optimal fitted model
a matrix with estimates and standard errors for the transition probabilities of the hidden Markov chain associated to TV random coefficients, if present for the optimal fitted model
the scale parameter for the optimal model
the standard deviation of error terms for the optimal model
the log-likelihood at convergence of the EM algorithm for the optimal model
the total number of model parameters for the optimal model
the AIC value for the optimal model
the BIC value for the optimal model
the estimated quantile
the number of mixture components associated to TC random coefficients, if present for the optimal fitted model
the number of hidden states associated to TV random coefficients, if present for the optimal fitted model
the number of subjects
the total number of observations
the missingness type
the identified optimal model
the matched call
a search_lqmix object
not used