| vcov.lqmix | R Documentation |
lqmix objectReturn the bootstrap variance-covariance matrix for the coefficients of a fitted lqmix object.
## S3 method for class 'lqmix'
vcov(object, ...)
object |
an |
... |
not used |
A matrix of the estimated covariances between the parameter estimates in the linear predictor of the model.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.