| vcov.lqr | R Documentation |
lqr objectReturn the bootstrap variance-covariance matrix for the parameters of a fitted lqr object.
## S3 method for class 'lqr'
vcov(object, ...)
object |
an |
... |
not used |
A matrix of the estimated covariances between the parameter estimates in the linear predictor of the model.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.