View source: R/vcov.search_lqmix.R
| vcov.search_lqmix | R Documentation |
Return the bootstrap variance-covariance matrix of the parameters of the optimal fitted model stored in an object of class search_lqmix.
## S3 method for class 'search_lqmix'
vcov(object, ...)
object |
an |
... |
not used |
A matrix of the estimated covariances between the main parameter estimates in the linear predictor of the model.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.